@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,11 +36,13 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.tpu_v2alpha1.services.tpu import pagers
-from google.cloud.tpu_v2alpha1.types import cloud_tpu
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import TpuTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.tpu_v2alpha1.services.tpu import pagers
+from google.cloud.tpu_v2alpha1.types import cloud_tpu
+
+from .transports.base import DEFAULT_CLIENT_INFO, TpuTransport
 from .transports.grpc import TpuGrpcTransport
 from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
 
@@ -57,7 +59,10 @@ class TpuClientMeta(type):
     _transport_registry["grpc"] = TpuGrpcTransport
     _transport_registry["grpc_asyncio"] = TpuGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[TpuTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[TpuTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -165,11 +170,15 @@ class TpuClient(metaclass=TpuClientMeta):
 
     @staticmethod
     def accelerator_type_path(
-        project: str, location: str, accelerator_type: str,
+        project: str,
+        location: str,
+        accelerator_type: str,
     ) -> str:
         """Returns a fully-qualified accelerator_type string."""
         return "projects/{project}/locations/{location}/acceleratorTypes/{accelerator_type}".format(
-            project=project, location=location, accelerator_type=accelerator_type,
+            project=project,
+            location=location,
+            accelerator_type=accelerator_type,
         )
 
     @staticmethod
@@ -182,10 +191,16 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def node_path(project: str, location: str, node: str,) -> str:
+    def node_path(
+        project: str,
+        location: str,
+        node: str,
+    ) -> str:
         """Returns a fully-qualified node string."""
         return "projects/{project}/locations/{location}/nodes/{node}".format(
-            project=project, location=location, node=node,
+            project=project,
+            location=location,
+            node=node,
         )
 
     @staticmethod
@@ -198,10 +213,16 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def runtime_version_path(project: str, location: str, runtime_version: str,) -> str:
+    def runtime_version_path(
+        project: str,
+        location: str,
+        runtime_version: str,
+    ) -> str:
         """Returns a fully-qualified runtime_version string."""
         return "projects/{project}/locations/{location}/runtimeVersions/{runtime_version}".format(
-            project=project, location=location, runtime_version=runtime_version,
+            project=project,
+            location=location,
+            runtime_version=runtime_version,
         )
 
     @staticmethod
@@ -214,7 +235,9 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -227,9 +250,13 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -238,9 +265,13 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -249,9 +280,13 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -260,10 +295,14 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -524,12 +563,20 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListNodesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -616,7 +663,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -732,7 +784,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -835,7 +892,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -859,7 +921,6 @@ class TpuClient(metaclass=TpuClientMeta):
         r"""Stops a node. This operation is only available with
         single TPU nodes.
 
-
         .. code-block:: python
 
             from google.cloud import tpu_v2alpha1
@@ -920,7 +981,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1003,7 +1069,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1124,7 +1195,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1148,7 +1224,6 @@ class TpuClient(metaclass=TpuClientMeta):
         r"""Generates the Cloud TPU service identity for the
         project.
 
-
         .. code-block:: python
 
             from google.cloud import tpu_v2alpha1
@@ -1205,7 +1280,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1297,12 +1377,20 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAcceleratorTypesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1391,7 +1479,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1483,12 +1576,20 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListRuntimeVersionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1577,7 +1678,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1646,7 +1752,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1667,7 +1778,9 @@ class TpuClient(metaclass=TpuClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-tpu",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-tpu",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
