@@ -15,23 +15,24 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 from google.cloud.tpu_v2alpha1.types import cloud_tpu
-from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-tpu",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-tpu",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -80,6 +81,7 @@ class TpuTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -121,25 +123,39 @@ class TpuTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_nodes: gapic_v1.method.wrap_method(
-                self.list_nodes, default_timeout=None, client_info=client_info,
+                self.list_nodes,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_node: gapic_v1.method.wrap_method(
-                self.get_node, default_timeout=None, client_info=client_info,
+                self.get_node,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_node: gapic_v1.method.wrap_method(
-                self.create_node, default_timeout=None, client_info=client_info,
+                self.create_node,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_node: gapic_v1.method.wrap_method(
-                self.delete_node, default_timeout=None, client_info=client_info,
+                self.delete_node,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.stop_node: gapic_v1.method.wrap_method(
-                self.stop_node, default_timeout=None, client_info=client_info,
+                self.stop_node,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.start_node: gapic_v1.method.wrap_method(
-                self.start_node, default_timeout=None, client_info=client_info,
+                self.start_node,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_node: gapic_v1.method.wrap_method(
-                self.update_node, default_timeout=None, client_info=client_info,
+                self.update_node,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.generate_service_identity: gapic_v1.method.wrap_method(
                 self.generate_service_identity,
@@ -162,7 +178,9 @@ class TpuTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_runtime_version: gapic_v1.method.wrap_method(
-                self.get_runtime_version, default_timeout=None, client_info=client_info,
+                self.get_runtime_version,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_guest_attributes: gapic_v1.method.wrap_method(
                 self.get_guest_attributes,
@@ -174,9 +192,9 @@ class TpuTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -313,5 +331,9 @@ class TpuTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("TpuTransport",)
